library(stockassessment)
load("run/model.RData")
#
# Input Parameters ####
# Reference points - WKNSEA Report
F_MSY <- 0.21
F_MSY_lower <- 0.173
F_MSY_upper <- 0.21
Fpa <- 0.21
Flim <- 0.31
Blim <- 17286
Bpa <- 25597
MSY_Btrigger <- 25597
# TAC & advice for current year
prev.advice <- 4114
prev.TAC <- 1800
# final year catch
cur.cat <- 1114
# Number of simulations
numberOfSims <- 1e4
#
# FORECAST ASSUMPTIONS ####
#
# Using the final year in the assessment (intermediate year) allows use of model 
# estimate int yr Rec
final.yr <- max(fit$data$years)
# Resample R from previous 10 years Rec
R.range <- seq(final.yr-9, final.yr, 1)
# Use final two years for mean weights & L-D partition
av.yrs <- seq(final.yr-2, final.yr-1, 1)
# Use 5 year average selection pattern
sel.yrs <- 2017:2021
# F status quo intermediate
f_mean <- fbartable(fit)[as.character(final.yr-1),"Estimate"] 
#
# Catch Scenarios ####
FC <- list()
# IntermediateF=Fsq then zero
set.seed(12345)
FC[[length(FC)+1]] <- forecast(fit, fscale = c(NA,0.0,0.0), fval = c(f_mean,NA,NA), year.base = final.yr, label = paste0(final.yr, "F=Fsq then zero"), rec.years = R.range, ave.years = av.yrs, overwriteSelYears = sel.yrs, nosim = 1e5, splitLD = TRUE)
# IntermediateF=Fsq then Fmsy
set.seed(12345)
FC[[length(FC)+1]] <- forecast(fit, fscale = c(NA,NA,NA), fval = c(f_mean,F_MSY,F_MSY), year.base = final.yr, label = paste0(final.yr, "F=Fsq then Fmsy"), rec.years = R.range, ave.years = av.yrs, overwriteSelYears = sel.yrs, nosim = 1e5, splitLD = TRUE)
# IntermediateF=Fsq then Fmsy lower
set.seed(12345)
FC[[length(FC)+1]] <- forecast(fit, fscale=c(NA,NA,NA), fval = c(f_mean,F_MSY_lower,F_MSY_lower), year.base = final.yr, label = paste0(final.yr, "F=Fsq then Fmsy lower"), rec.years = R.range, ave.years = av.yrs, overwriteSelYears = sel.yrs,nosim = 1e5, splitLD = TRUE)
# IntermediateF=Fsq then Fmsy upper
set.seed(12345)
FC[[length(FC)+1]] <- forecast(fit, fscale = c(NA,NA,NA), fval = c(f_mean,F_MSY_upper,F_MSY_upper), year.base = final.yr, label = paste0(final.yr, "F=Fsq then Fmsy upper"), rec.years = R.range, ave.years = av.yrs, overwriteSelYears = sel.yrs, nosim = 1e5, splitLD = TRUE)
# IntermediateF=Fsq then Fpa 
set.seed(12345)
FC[[length(FC)+1]] <- forecast(fit, fscale = c(NA,NA,NA), fval = c(f_mean,Fpa,Fpa), year.base = final.yr, label = paste0(final.yr, "F=Fsq then Fpa"), rec.years = R.range, ave.years = av.yrs, overwriteSelYears = sel.yrs, nosim = 1e5, splitLD = TRUE)
# IntermediateF=Fsq then Flim 
set.seed(12345)
FC[[length(FC)+1]] <- forecast(fit, fscale = c(NA,NA,NA), fval = c(f_mean,Flim,Flim), year.base = final.yr, label = paste0(final.yr, "F=Fsq then Flim"), rec.years = R.range, ave.years = av.yrs, overwriteSelYears = sel.yrs, nosim = 1e5, splitLD = TRUE)
# SQ
set.seed(12345)
FC[[length(FC)+1]] <- forecast(fit, fscale = c(NA,NA,NA), fval = c(f_mean,f_mean,f_mean), year.base = final.yr, label = paste0(final.yr, "F=Fsq then Fsq"), rec.years = R.range, ave.years = av.yrs, overwriteSelYears = sel.yrs, nosim = 1e5, splitLD = TRUE)
# F=0.05
set.seed(12345)
FC[[length(FC)+1]] <- forecast(fit, fscale = c(NA,NA,NA), fval = c(f_mean,0.05,0.05), year.base = final.yr, label = paste0(final.yr, "F=Fsq then F=0.05"), rec.years = R.range, ave.years = av.yrs, overwriteSelYears = sel.yrs, nosim = 1e5, splitLD = TRUE)
# IntermediateF=Fsq then SSB=Blim
set.seed(12345)
FC[[length(FC)+1]] <- forecast(fit, fscale = c(NA,NA,NA), fval = c(f_mean,NA,f_mean), nextssb = c(NA,Blim,NA), year.base = final.yr, label = paste0(final.yr, "F=Fsq then SSB=Blim"), rec.years = R.range, ave.years = av.yrs, overwriteSelYears = sel.yrs, nosim = 1e5, splitLD = TRUE)
# IntermediateF=Fsq then SSB=Bpa
set.seed(12345)
FC[[length(FC)+1]] <- forecast(fit, fscale = c(NA,NA,NA), fval = c(f_mean,NA,f_mean), nextssb = c(NA,Bpa,NA), year.base = final.yr, label = paste0(final.yr, "F=Fsq then SSB=Bpa"), rec.years = R.range, ave.years = av.yrs, overwriteSelYears = sel.yrs, nosim = 1e5, splitLD = TRUE)
# IntermediateF=Fsq then SSB=MSYBtrigger
set.seed(12345)
FC[[length(FC)+1]] <- forecast(fit, fscale = c(NA,NA,NA), fval = c(f_mean,NA,f_mean), nextssb = c(NA,MSY_Btrigger,NA), year.base = final.yr, label = paste0(final.yr, "F=Fsq then SSB=MSYBtrigger"), rec.years = R.range, ave.years = av.yrs, overwriteSelYears = sel.yrs, nosim = 1e5, splitLD = TRUE)
# IntermediateF=Fsq then catch=prev.TAC
set.seed(12345)
FC[[length(FC)+1]] <- forecast(fit, fval = c(f_mean,NA,NA), catchval=c(NA,prev.TAC,prev.TAC), year.base = final.yr, label = paste0(final.yr, "F=Fsq then prev.TAC"), rec.years = R.range, ave.years = av.yrs, overwriteSelYears = sel.yrs, nosim = 1e5, splitLD = TRUE)
# IntermediateF=Fsq then catch=final_catch
set.seed(12345)
FC[[length(FC)+1]] <- forecast(fit, fval = c(f_mean,NA,NA), catchval = c(NA,cur.cat,cur.cat), year.base = final.yr, label = paste0(final.yr, "F=Fsq then ", final.yr-1, "catch"), rec.years = R.range, ave.years = av.yrs, overwriteSelYears = sel.yrs, nosim = 1e5, splitLD = TRUE) 
# Save output
save(FC, file="run/forecast.RData")
